from datetime import datetime
from netcdf import netcdf as nc
from channels import channel_01


short = (lambda f, start=2, end=-2:
         ".".join((f.split('/')[-1]).split('.')[start:end]))
get_datetime = lambda f: datetime.strptime(short(f, 1), '%Y.%j.%H%M%S')
channels = {
    1: channel_01,
}


def calibration(date, satellite, channel=1):
    """
    Return the calibration parameters.

    Keyword arguments:
    satellite -- the name of the satellite.
    date --  the datetime of an image.
    channel -- the channel number.
    """
    return channels[channel].calibration(date, satellite)


def calibration_to(filename):
    """
    Return the calibration parameters.

    Keyword arguments:
    filename -- the name of a netcdf file.
    """
    satellite = short(filename, 0, 1)
    return calibration(get_datetime(filename), satellite)


def calibrate(filename):
    """
    Append the calibration parameters as variables of the netcdf file.

    Keyword arguments:
    filename -- the name of a netcdf file.
    """
    params = calibration_to(filename)
    with nc.loader(filename) as root:
        for key, value in params.items():
            nc.getdim(root, 'xc_1', 1)
            nc.getdim(root, 'yc_1', 1)
            if isinstance(value, list):
                for i in range(len(value)):
                    nc.getvar(root, '%s_%i' % (key, i), 'f4', ('time', 'yc_1', 'xc_1' ))[:] = value[i]
            else:
                nc.getvar(root, key, 'f4', ('time', 'yc_1', 'xc_1'))[:] = value
